pub enum ApprovalStateRes {
Accepted,
Rejected,
Obsolete,
}Variants
Accepted
Request for approval which is in responded status and accepted
Rejected
Request for approval which is in responded status and rejected
Obsolete
The approval entity is obsolete.