Ave Common
Common types and utilities for Ave without heavy dependencies.
This crate re-exports essential types needed for working with Ave, such as identity and cryptography, without pulling in heavy dependencies like wasmtime that don’t compile on all architectures.
Re-exports
pub use error::ConversionError;pub use error::Error;pub use error::SignatureError;pub use schematype::SchemaType;pub use namespace::Namespace;pub use wrapper::ValueWrapper;pub use ave_identity as identity;pub use bridge::*;pub use sink::*;
Modules
- bridge
- error
- Error types for Ave Common
- governance
- namespace
- Namespace model.
- request
- schematype
- sink
- wrapper